grab.spider.service.parser — Grab 0.6.41 documentation

# `grab.spider.service.parser`

## Module Contents

### Classes

`ParserService` |

class grab.spider.service.parser.ParserService(fatal_error_queue: queue.Queue[grab.spider.interface.FatalErrorQueueItem], pool_size: int, task_dispatcher: grab.spider.service.task_dispatcher.TaskDispatcherService, stat: procstat.Stat, parser_requests_per_process: int, find_task_handler: collections.abc.Callable[[grab.spider.task.Task], collections.abc.Callable[Ellipsis, None]])

  Bases: `grab.spider.service.base.BaseService`

  check_pool_health() → None
  supervisor_callback(worker: grab.spider.service.base.ServiceWorker) → None
  worker_callback(worker: grab.spider.service.base.ServiceWorker) → None
  execute_task_handler(handler: collections.abc.Callable[[grab.base.Grab, grab.spider.task.Task], None], result: grab.spider.service.network.NetworkResult, task: grab.spider.task.Task) → None